Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code | Sign in
(27)

Unified Diff: state/export_test.go

Issue 5671055: Implementation of the charm state. (Closed)
Patch Set: Implementation of the charm state. Created 13 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Please Sign in to add in-line comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « state/charm.go ('k') | state/internal_test.go » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: state/export_test.go
=== fwereade@gmail.com-20120227101839-rentvkf9hp3jhpsx > themue@gmail.com-20120227182538-taj4hdi2vrahw7h3
=== modified file 'state/export_test.go'
--- state/export_test.go 2012-02-10 09:00:54 +0000
+++ state/export_test.go 2012-02-24 10:37:03 +0000
@@ -1,18 +1,50 @@
+// launchpad.net/juju/state
+//
+// Copyright (c) 2011-2012 Canonical Ltd.
package state
import (
- . "launchpad.net/gocheck"
+ "fmt"
+ "io/ioutil"
"launchpad.net/gozk/zookeeper"
+ "os"
+ "testing"
)
-// OpenAddr connects to the single server at the given address
-// and returns its State and the State's zookeeper connection.
-// It is defined in export_test.go so that tests can have access to
-// the underlying zookeeper connection as well as the State.
-func OpenAddr(c *C, addr string) (st *State, zk *zookeeper.Conn) {
- st, err := Open(&Info{
- Addrs: []string{addr},
- })
- c.Assert(err, IsNil)
- return st, st.zk
+// ZkAddr is the address for the connection to the server.
+var ZkAddr string
+
+// ZkSetUpEnvironment initializes the ZooKeeper test environment.
+func ZkSetUpEnvironment(t *testing.T) (*zookeeper.Server, string) {
+ dir, err := ioutil.TempDir("", "statetest")
+ if err != nil {
+ t.Fatalf("cannot create temporary directory: %v", err)
+ }
+ testRoot := dir + "/zookeeper"
+ testPort := 21812
+ srv, err := zookeeper.CreateServer(testPort, testRoot, "")
+ if err != nil {
+ t.Fatalf("cannot create ZooKeeper server: %v", err)
+ }
+ err = srv.Start()
+ if err != nil {
+ t.Fatalf("cannot start ZooKeeper server: %v", err)
+ }
+ ZkAddr = fmt.Sprint("localhost:", testPort)
+ return srv, dir
+}
+
+// ZkTearDownEnvironment destroys the ZooKeeper test environment.
+func ZkTearDownEnvironment(t *testing.T, srv *zookeeper.Server, dir string) {
+ srv.Destroy()
+ if err := os.RemoveAll(dir); err != nil {
+ t.Fatal("cannot remove temporary directory: %v", err)
+ }
+}
+
+// ZkConn returns the ZooKeeper connection used by a state.
+// It is defined in export_test.go so that tests can have access
+// to this connection.
+func ZkConn(st *State) *zookeeper.Conn {
+ return st.zk
}
« no previous file with comments | « state/charm.go ('k') | state/internal_test.go » ('j') | no next file with comments »

Powered by Google App Engine
RSS Feeds Recent Issues | This issue
This is Rietveld f62528b